@@ -6,11 +6,12 @@
 # @Software: PyCharm
 
 
-def create_in_sql(table_name: str, data: dict, conversion=False):
+def create_in_sql(table_name: str, data: dict, conversion=False, update=False):
     """
     传入字典和表名，返回组装好的sql
     sql中的插入字段为传入字典的key
     conversion:是否全部转换成字符串类型
+    update:是否启动更新语句
     data = {'w':'d1','ew':'d2','wr':'d3','wa':'d4'}
     """
     sql = 'insert into ' + table_name + ' ('
@@ -30,5 +31,12 @@ def create_in_sql(table_name: str, data: dict, conversion=False):
                 else:
                     sql += f'{value},'
             sql = sql.rstrip(',')
-            sql += ");"
+    if update:
+        sql += ")  ON DUPLICATE KEY UPDATE "
+        for key in data_keys:
+            sql += key + '=' + f'values({key}),'
+        sql = sql.rstrip(',')
+        sql += ";"
+    else:
+        sql += ");"
     return sql
